@@ -24,11 +24,14 @@ class SegmentConfiguration:
     in this segment configuration.
     """
 
-    def __init__(self, type: SegmentType):
+    def __init__(self, type: SegmentType, string_durations = None):
         self.type = type,
         self.modes = None, # By now we don't accept modes
         self.default_mode = None # By now we don't accept modes
-        self.string_durations = None # By now we don't accept string durations here
+        self.string_durations = None 
+
+        if string_durations is not None:
+            self.string_durations = string_durations
 
     # TODO: Should we keep this below (?)
     @staticmethod
@@ -581,6 +584,7 @@ class MemeConfiguration(Configuration):
 
     _config_as_segment: SegmentConfiguration = SegmentConfiguration(
         type = SegmentType.MEME,
+        string_durations = [EnhancementStringDuration.FILE_DURATION]
     )
     _config_as_enhancement: EnhancementConfiguration = EnhancementConfiguration(
         type = EnhancementType.MEME,
