@@ -1,7 +1,8 @@
 from youtube_autonomous.elements.builder.element_builder import ElementBuilder
-from youtube_autonomous.segments.enums import EnhancementField
 from youtube_autonomous.elements.validator.element_parameter_validator import ElementParameterValidator
 from yta_multimedia.video.edition.effect.moviepy.black_and_white_moviepy_effect import BlackAndWhiteMoviepyEffect
+from yta_multimedia.video.edition.effect.moviepy.blink_moviepy_effect import BlinkMoviepyEffect
+from yta_multimedia.video.edition.effect.zoom.linear_zoom_video_effect import LinearZoomVideoEffect
 from moviepy.editor import VideoFileClip, CompositeVideoClip, ColorClip, ImageClip, AudioFileClip, AudioClip, CompositeAudioClip
 from typing import Union
 
@@ -13,8 +14,6 @@ class EffectElementBuilder(ElementBuilder):
     @classmethod
     def build_from_enhancement(cls, enhancement: dict):
         effect_name = enhancement.keywords
-        extra_parameters = {}   # TODO: Get these
-
         effect = cls.effect_name_to_class(effect_name)
 
         return effect
@@ -35,6 +34,10 @@ class EffectElementBuilder(ElementBuilder):
         
         if effect_name == 'black_and_white':
             effect = BlackAndWhiteMoviepyEffect
+        elif effect_name == 'blink':
+            effect = BlinkMoviepyEffect
+        elif effect_name == 'zoom':
+            effect = LinearZoomVideoEffect
 
         return effect
 
