@@ -9,11 +9,14 @@ from youtube_autonomous.elements.rules.rules_checker import RulesChecker
 from youtube_autonomous.segments.builder.config import DEFAULT_SEGMENT_PARTS_FOLDER
 from youtube_autonomous.segments.enums import EnhancementMode, EnhancementType
 from yta_multimedia.audio.voice.transcription.stt.whisper import get_transcription_with_timestamps
+from yta_multimedia.audio.sound.generation.sound_generator import SoundGenerator
+from yta_multimedia.video.edition.effect.moviepy.moviepy_effect import MoviepyEffect
+from yta_multimedia.video.edition.effect.video_effect import VideoEffect
 from yta_general_utils.file import copy_file
 from yta_general_utils.file.filename import get_file_extension
 from yta_general_utils.temp import get_temp_filename
-from yta_general_utils.logger import print_completed
-from moviepy.editor import AudioFileClip, VideoFileClip, CompositeVideoClip, concatenate_videoclips
+from yta_general_utils.logger import print_completed, print_in_progress
+from moviepy.editor import AudioFileClip, VideoFileClip, CompositeVideoClip, concatenate_videoclips, CompositeAudioClip
 
 
 class Segment:
@@ -46,6 +49,8 @@ class Segment:
 
     enhancements: list
 
+    extra_params: dict
+
     narration_text_sanitized_without_shortcodes: str
     narration_text_with_simplified_shortcodes: str
     narration_text_sanitized: str
@@ -213,6 +218,12 @@ class Segment:
         # 5. Update enhancements duration according to base video
         # TODO: What if 'start' is after the end of the base video (?)
         for index, enhancement in enumerate(self.enhancements):
+            # With this condition we avoid the None enhancements that are 
+            # generated due to the gap between the start indexes and the
+            # ones we generate with +100 because of edition manual
+            if enhancement is None:
+                continue
+
             if enhancement.duration == StringDuration.SEGMENT_DURATION.name:
                 enhancement.duration = self.video_clip.duration
 
@@ -228,6 +239,9 @@ class Segment:
                 # start as we are enlarging the video when applying this
                 # inline enhancement
                 for i in range(index + 1, len(self.enhancements)):
+                    if self.enhancements[i] is None:
+                        continue
+                    
                     if self.enhancements[i].start >= enhancement.start:
                         self.enhancements[i].start += enhancement.duration
             
@@ -243,6 +257,9 @@ class Segment:
         # inline effects, it will fail
         enhancement_clips = []
         for enhancement in sorted(self.enhancements, key = lambda enhancement: enhancement.start):
+            if enhancement is None:
+                continue
+
             enhancement_clip = enhancement.build()
             # TODO: Combine with our segment according to type
 
@@ -259,7 +276,6 @@ class Segment:
                         enhancement_clip,
                         self.video_clip
                     ])
-                print('built inline enhancement')
             elif enhancement.mode == EnhancementMode.OVERLAY.value:
                 compound_clip = CompositeVideoClip([
                     self.video_clip.subclip(enhancement.start, end),
@@ -280,18 +296,24 @@ class Segment:
                         compound_clip
                     ])
                 else:
-                    self.video_clip = concatenate_videoclips[(
+                    self.video_clip = concatenate_videoclips([
                         self.video_clip.subclip(0, enhancement.start),
                         compound_clip,
                         self.video_clip.subclip(end, self.video_clip.duration)
-                    )]
+                    ])
                 # TODO: Could happen that duration is longer than self.video_clip.duration (?)
-                print('built overlay enhancement')
             elif enhancement.mode == EnhancementMode.REPLACE.value:
                 if enhancement.type in [EnhancementType.EFFECT.value, EnhancementType.EFFECT]:
-                    # TODO: Obtain parameters from somewhere
-                    parameters = {}
-                    enhancement_clip = enhancement_clip(self.video_clip.subclip(enhancement.start, end)).apply(**parameters)
+                    # TODO: These 'extra_params' must be set and correctly checked before
+                    # Here 'enhancement_clip' is the effect class, so we need to apply it
+                    # correctly
+                    parameters = enhancement.extra_params
+
+                    if issubclass(enhancement_clip, MoviepyEffect):
+                        enhancement_clip = enhancement_clip(clip = self.video_clip.subclip(enhancement.start, end), **parameters).apply()
+                    elif issubclass(enhancement_clip, VideoEffect):
+                        enhancement_clip = enhancement_clip(video = self.video_clip.subclip(enhancement.start, end)).apply(**parameters)
+                    # TODO: What about 'BasePositionMoviepyEffect' (?)
                 elif enhancement.type in [EnhancementType.GREENSCREEN.value, EnhancementType.GREENSCREEN]:
                     # TODO: Send parameters (I don't know how actually)
                     enhancement_clip = enhancement_clip.from_video_to_video(self.video_clip.subclip(enhancement.start, end))
@@ -314,7 +336,6 @@ class Segment:
                         enhancement_clip,
                         self.video_clip.subclip(end, self.video_clip.duration)
                     ])
-                print('built replace enhancement')
 
     def build(self):
         if self.rules_checker.should_build_narration_rule(self):
@@ -337,12 +358,36 @@ class Segment:
             self.duration = self.audio_clip.duration
 
         if not self.video_clip:
-            print('Building base content step 4')
+            print_in_progress('Building base content step 4')
             self.build_step_4_build_base_content()
+            print_completed('Base content built in step 4')
+
+        # This would be the real duration that could be not the
+        # one in the database as this is in real time and it is
+        # not updated in the database
+        self.duration = self.video_clip.duration
 
         # Make the base video to apply enhancements on it
         if self.audio_clip:
-            self.video_clip = self.video_clip.set_audio(self.audio_clip)
+            # If we have another audio clip we should want to put
+            # them togeter, not to replace it
+            audio = self.audio_clip
+            if self.video_clip.audio:
+                # We have another audio, we need to put them together
+                audio = CompositeAudioClip([
+                    self.video_clip.audio,
+                    audio
+                ])
+                
+            # TODO: Should we replace self.audio_clip (?)
+            self.video_clip = self.video_clip.set_audio(audio)
+        elif not self.video_clip.audio:
+            # Premade and other type of video_clip can have audio
+            # by themselves, but another type of videos cannot, so
+            # we need to put silence audio to have an audio track
+            # or we will have issues when concatenating with ffmpeg
+            # only in those without audio
+            self.video_clip = self.video_clip.set_audio(SoundGenerator().create_silence_audio(self.video_clip.duration))
 
         self.build_step_5_update_enhancements_duration()
         # TODO: By now I'm omitting this part
