@@ -1,16 +1,21 @@
 from youtube_autonomous.database.database_handler import DatabaseHandler
 from youtube_autonomous.experimental.segments.validation.segment_validator import SegmentValidator
 from youtube_autonomous.shortcodes.objects.shortcode_tag import ShortcodeTag
+from youtube_autonomous.elements.builder.premade_element_builder import PremadeElementBuilder
+from youtube_autonomous.elements.builder.effect_element_builder import EffectElementBuilder
+from youtube_autonomous.elements.builder.text_element_builder import TextElementBuilder
 from youtube_autonomous.shortcodes.enums import ShortcodeTagType
 from youtube_autonomous.elements.validator.element_validator import ElementValidator
 from youtube_autonomous.elements.rules.element_rules import ElementRules
 from youtube_autonomous.project.project import Project
-from youtube_autonomous.enums import StringDuration
+from youtube_autonomous.enums import StringDuration, SegmentType, EnhancementType
 from youtube_autonomous.elements.rules.rules_checker import RulesChecker
 from youtube_autonomous.segments.enums import SegmentField, EnhancementField, ProjectStatus, SegmentStatus
 from youtube_autonomous.elements.validator.element_parameter_validator import ElementParameterValidator
 from youtube_autonomous.segments.builder.config import DEFAULT_SEGMENT_PARTS_FOLDER, DEFAULT_PROJECTS_OUTPUT_FOLDER
 from youtube_autonomous.shortcodes.shortcode_parser import ShortcodeParser
+from yta_multimedia.video.edition.effect.moviepy.moviepy_effect import MoviepyEffect
+from yta_multimedia.video.edition.effect.video_effect import VideoEffect
 from yta_general_utils.temp import clean_temp_folder
 from yta_general_utils.programming.path import get_project_abspath
 from yta_general_utils.path import create_file_abspath
@@ -150,6 +155,16 @@ class YoutubeAutonomous:
 
             # We can only accept 'FILE_DURATION' for some specific types
             ElementValidator.validate_segment_duration_field_for_type(duration, type)
+
+            # TODO: Validate, if premade or effect, that 'extra_data' has
+            # needed fields
+            keywords = segment.get(SegmentField.KEYWORDS.value, None)
+            if type == SegmentType.PREMADE.value:
+                # This will raise an Exception if no mandatory parameters are given
+                PremadeElementBuilder.extract_extra_params(segment, PremadeElementBuilder.premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'duration'])
+            elif type == SegmentType.TEXT.value:
+                TextElementBuilder.extract_extra_params(segment, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration'])
+            # TODO: Validate for another types
             
             for index, enhancement in enumerate(segment.get(SegmentField.ENHANCEMENTS.value, [])):
                 print_in_progress(f'   Handling enhancement [{index}]')
@@ -189,6 +204,25 @@ class YoutubeAutonomous:
                 RulesChecker.check_need_rules(enhancement, ElementRules.get_subclass_by_type(enhancement_type)())
                 # TODO: We should check any other thing that is here (frames, etc.)
 
+                # TODO: Validate, if premade or effect, that 'extra_data' has
+                # needed fields
+                keywords = enhancement.get(EnhancementField.KEYWORDS.value, None)
+                if enhancement_type == EnhancementType.PREMADE.value:
+                    # This will raise an Exception if no mandatory parameters are given
+                    PremadeElementBuilder.extract_extra_params(enhancement, PremadeElementBuilder.premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'duration'])
+                elif enhancement_type == EnhancementType.EFFECT.value:
+                    effect_class = EffectElementBuilder.effect_name_to_class(keywords)
+
+                    if issubclass(effect_class, MoviepyEffect):
+                        # Params are in the init, removing 'clip'
+                        EffectElementBuilder.extract_extra_params(enhancement, effect_class.__init__, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'clip'])
+                    elif issubclass(effect_class, VideoEffect):
+                        # Params are in the apply, removing 'video'
+                        EffectElementBuilder.extract_extra_params(enhancement, effect_class.apply, params_to_ignore = ['self', 'cls', 'args', 'kwargs', 'video'])
+                elif enhancement_type == EnhancementType.TEXT.value:
+                    TextElementBuilder.extract_extra_params(enhancement, TextElementBuilder.text_premade_name_to_class(keywords).generate, ['self', 'cls', 'args', 'kwargs', 'output_filename', 'duration'])
+                # TODO: Validate for another types
+
             # 4. If doesn't have necessary fields for its type
             RulesChecker.check_need_rules(segment, ElementRules.get_subclass_by_type(type)())
     
